@@ -9,7 +9,7 @@
 #
 package Reindeer;
 {
-  $Reindeer::VERSION = '0.007';
+  $Reindeer::VERSION = '0.008';
 }
 
 # ABSTRACT: Moose with more antlers
@@ -59,7 +59,7 @@ Reindeer - Moose with more antlers
 
 =head1 VERSION
 
-This document describes 0.007 of Reindeer - released February 14, 2012 as part of Reindeer.
+This document describes 0.008 of Reindeer - released February 28, 2012 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -247,12 +247,23 @@ subclass before it is invoked, and before the subclass is made immutable.
 
 requires() is a synonym for abstract() and works in the way you'd expect.
 
+=head1 OVERLOADS
+
+It is safe to use overloads in your Reindeer classes and roles; they will
+work just as you expect: overloads in classes can be inherited by subclasses;
+overloads in roles will be incorporated into consuming classes.
+
+(See also L<MooseX::MarkAsMethods>)
+
 =head1 AVAILABLE OPTIONAL ATTRIBUTE TRAITS
 
-We make available the following trait aliases.  These traits are NOT
-automatically applied to attributes, and can be used as:
+We export the following trait aliases.  These traits are not
+automatically applied to attributes, and are lazily loaded (e.g. if you don't
+use them, they won't be loaded and are not dependencies).
 
-    has foo => (traits => [ AutoDestruct ], ...);
+They can be used by specifying them as:
+
+    has foo => (traits => [ TraitAlias ], ...);
 
 =head2 AutoDestruct
 
@@ -287,6 +298,31 @@ See L<MooseX::MultiInitArg> for more information.
 
 =head2 UndefTolerant
 
+Applying this trait to your attribute makes it's initialization tolerant of
+of undef.  If you specify the value of undef to any of the attributes they
+will not be initialized (or will be set to the default, if applicable).
+Effectively behaving as if you had not provided a value at all.
+
+    package My:Class;
+    use Moose;
+
+    use MooseX::UndefTolerant::Attribute;
+
+    has 'bar' => (
+        traits    => [ UndefTolerant ],
+        is        => 'ro',
+        isa       => 'Num',
+        predicate => 'has_bar'
+    );
+
+    # Meanwhile, under the city...
+
+    # Doesn't explode
+    my $class = My::Class->new(bar => undef);
+    $class->has_bar # False!
+
+See L<MooseX::UndefTolerant::Attribute> for more information.
+
 =head1 INCLUDED EXTENSIONS
 
 Reindeer includes the traits and sugar provided by the following extensions.
@@ -339,14 +375,77 @@ before autoclean is unleashed, so Everything Will Just Work as Expected.
 
 =head2 L<Path::Class>
 
+  use Path::Class;
+  
+  my $dir  = dir('foo', 'bar');       # Path::Class::Dir object
+  my $file = file('bob', 'file.txt'); # Path::Class::File object
+  
+  # Stringifies to 'foo/bar' on Unix, 'foo\bar' on Windows, etc.
+  print "dir: $dir\n";
+  
+  # Stringifies to 'bob/file.txt' on Unix, 'bob\file.txt' on Windows
+  print "file: $file\n";
+  
+  my $subdir  = $dir->subdir('baz');  # foo/bar/baz
+  my $parent  = $subdir->parent;      # foo/bar
+  my $parent2 = $parent->parent;      # foo
+  
+  my $dir2 = $file->dir;              # bob
+
+  # Work with foreign paths
+  use Path::Class qw(foreign_file foreign_dir);
+  my $file = foreign_file('Mac', ':foo:file.txt');
+  print $file->dir;                   # :foo:
+  print $file->as_foreign('Win32');   # foo\file.txt
+  
+  # Interact with the underlying filesystem:
+  
+  # $dir_handle is an IO::Dir object
+  my $dir_handle = $dir->open or die "Can't read $dir: $!";
+  
+  # $file_handle is an IO::File object
+  my $file_handle = $file->open($mode) or die "Can't read $file: $!";
+
+See the L<Path::Class> documentation for more detail.
+
 =head2 L<Try::Tiny>
 
+You can use Try::Tiny's C<try> and C<catch> to expect and handle exceptional
+conditions, avoiding quirks in Perl and common mistakes:
+
+	# handle errors with a catch handler
+	try {
+		die "foo";
+	} catch {
+		warn "caught error: $_"; # not $@
+	};
+
+You can also use it like a stanalone C<eval> to catch and ignore any error
+conditions.  Obviously, this is an extreme measure not to be undertaken
+lightly:
+
+	# just silence errors
+	try {
+		die "foo";
+	};
+
+See the L<Try::Tiny> documentation for more detail.
+
 =head1 CAVEAT
 
 This author is applying his own assessment of "useful/popular extensions".
 You may find yourself in agreement, or violent disagreement with his choices.
 YMMV :)
 
+=head1 ACKNOWLEDGMENTS
+
+Reindeer serves largely to tie together other packages -- Moose extensions and
+other common modules.  Those other packages are largely by other people,
+without whose work Reindeer would have a significantly smaller rack.
+
+We also use documentation as written for the other packages pulled in here to
+help present a cohesive whole.
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
